@@ -202,3 +202,33 @@ def str2short_str(value: str, n: int = 5, chars=string.ascii_letters + string.di
 
 def eliminate_empty(data: list):
     return [x for x in data if x is not None]
+
+
+def find_child(data, key="id", parent_key="parent_id"):
+    result = []
+    obj = {}
+    for x in data:
+        obj[x.get(key)] = x
+    for x in data:
+        parent_key_value = x.get(parent_key)
+        parent = obj.get(parent_key_value, {})
+        if parent:
+            if not parent.get("children"):
+                parent["children"] = []
+            if not x.get("children"):
+                x["children"] = []
+            parent["children"].append(x)
+        else:
+            if not x.get("children"):
+                x["children"] = []
+            result.append(x)
+    return result
+
+
+def dict2list(data: dict, data_key="count", key_name="key", value_name="value"):
+    result = []
+    for key, value in data.items():
+        if data_key:
+            value = value.get(data_key)
+        result.append({key_name: key, value_name: value})
+    return result
